from django.apps import AppConfig


class DynDatatablesConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'django_dyn_dt'
